@@ -1,9 +1,10 @@
+import json
+
 import boto3
 
 from samslacker.resources import Events
 
-api_base = 'https://samplify.io/slacker/api'
-sns_arn = 'arn:aws:sns:us-east-1:319868825377:sam-slacker-event-created'
+api_base = 'https://slacker.kipwise.com/api'
 api_version = 'v1'
 token = None
 project = None
@@ -21,7 +22,7 @@ def event(_name, *args, **kwargs):
     if project is not None:
         data['project_id'] = project
 
-    sns_resource = boto3.resource('sns')
+    sns_resource = boto3.resource('sns', region_name=aws_region)
     return sns_resource.Topic(sns_arn).publish(
-        Message=data,
+        Message=json.dumps(data),
     )
